% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_nuts.R
\name{.message}
\alias{.message}
\title{Compact message printer}
\usage{
.message(x)
}
\description{
Compact message printer
}
\keyword{internal}
