% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/map_nuts.R
\name{.build_map_data}
\alias{.build_map_data}
\title{Build map data (frequencies, splits, and an auto-zoom extent)}
\usage{
.build_map_data(shp, df, nuts_col, country_shp = NULL)
}
\description{
Build map data (frequencies, splits, and an auto-zoom extent)
}
\keyword{internal}
